@@ -7,9 +7,9 @@ use warnings;
 use Business::OnlinePayment;
 use Business::OnlinePayment::HTTPS;
 use parent qw(Business::OnlinePayment::HTTPS);
-our $me      = 'Business::OnlinePayment::Mock';
+our $me = 'Business::OnlinePayment::Mock';
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 # PODNAME: Business::OnlinePayment::Mock
 # ABSTRACT: Business::OnlinePayment::Mock - A backend for mocking fake results for test cards
 
@@ -31,6 +31,7 @@ sub _info {
         supported_types   => ['CC'],
         supported_actions => {
             CC => [
+
                 # 'Tokenize', # TODO
                 'Normal Authorization',
                 'Post Authorization',
@@ -54,7 +55,7 @@ sub set_default_mock {
 sub set_mock_response {
     my ($self, $response, $set_as_default) = @_;
 
-    $mock_responses->{delete $response->{'action'}}->{delete $response->{'card_number'}} = $response;
+    $mock_responses->{ delete $response->{'action'} }->{ delete $response->{'card_number'} } = $response;
 
     $self->set_as_default($response) if $set_as_default;
 }
@@ -73,22 +74,25 @@ sub test_transaction {
 
 
 sub submit {
-    my $self = shift;
+    my $self    = shift;
     my %content = $self->content();
     die 'Missing action' unless $content{'action'};
 
     my $action;
-    foreach my $a (@{$self->_info()->{'supported_actions'}->{'CC'}}) {
+    foreach my $a (@{ $self->_info()->{'supported_actions'}->{'CC'} }) {
         if (lc $a eq lc $content{'action'}) {
-            $action = $a; last;
+            $action = $a;
+            last;
         }
     }
     die 'Unsupported action' unless $action;
 
-    my $result       = {%{$mock_responses->{$action}->{$content{'card_number'}} || $default_mock}}; # cheap clone
-    foreach my $k (keys %$result) {
+    my $result = { %{ $mock_responses->{$action}->{ $content{'card_number'} } || $default_mock } };    # cheap clone
+
+    foreach my $k (keys %{$result}) {
         my $val = $result->{$k};
-        $self->$k( ref $val eq 'CODE' ? $val->(\%content) : $val ) if $self->can($k);
+        $result->{$k} = ref $val eq 'CODE' ? $val->(\%content) : $val;
+        $self->$k($result->{$k}) if $self->can($k);
     }
 
     return $result;
@@ -108,7 +112,7 @@ Business::OnlinePayment::Mock - Business::OnlinePayment::Mock - A backend for mo
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
